@@ -23,10 +23,12 @@ __copyright__ = '(C) 2015, Giovanni Manghi'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '307d082e3de804064a7295aa079ee6cd0e47845a'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 from qgis.core import (QgsProcessing,
+                       QgsProcessingException,
                        QgsProcessingParameterDefinition,
+                       QgsProcessingParameterDistance,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterEnum,
                        QgsProcessingParameterField,
@@ -62,10 +64,10 @@ class OneSideBuffer(GdalAlgorithm):
         self.addParameter(QgsProcessingParameterString(self.GEOMETRY,
                                                        self.tr('Geometry column name'),
                                                        defaultValue='geometry'))
-        self.addParameter(QgsProcessingParameterNumber(self.DISTANCE,
-                                                       self.tr('Buffer distance'),
-                                                       type=QgsProcessingParameterNumber.Double,
-                                                       defaultValue=10))
+        self.addParameter(QgsProcessingParameterDistance(self.DISTANCE,
+                                                         self.tr('Buffer distance'),
+                                                         defaultValue=10,
+                                                         parentParameterName=self.INPUT))
         self.addParameter(QgsProcessingParameterEnum(self.BUFFER_SIDE,
                                                      self.tr('Buffer side'),
                                                      options=self.bufferSides,
@@ -111,7 +113,11 @@ class OneSideBuffer(GdalAlgorithm):
         return 'ogr2ogr'
 
     def getConsoleCommands(self, parameters, context, feedback, executing=True):
-        fields = self.parameterAsSource(parameters, self.INPUT, context).fields()
+        source = self.parameterAsSource(parameters, self.INPUT, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+
+        fields = source.fields()
         ogrLayer, layerName = self.getOgrCompatibleSource(self.INPUT, parameters, context, feedback, executing)
         geometry = self.parameterAsString(parameters, self.GEOMETRY, context)
         distance = self.parameterAsDouble(parameters, self.DISTANCE, context)
