@@ -23,7 +23,7 @@ __copyright__ = '(C) 2017, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 import os
 
 
@@ -34,10 +34,10 @@ def checkParameterValuesBeforeExecuting(alg, parameters, context):
     step = alg.parameterAsDouble(parameters, 'step', context)
 
     if start >= end:
-        return alg.tr("The start position must be inferior to the end position!")
+        return False, alg.tr("The start position must be inferior to the end position!")
     if step == 0.0:
-        return alg.tr("The step must be greater than zero!")
-    return None
+        return False, alg.tr("The step must be greater than zero!")
+    return True, None
 
 
 def processOutputs(alg, parameters, context, feedback):
