@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 
 def checkParameterValuesBeforeExecuting(alg, parameters, context):
@@ -31,9 +31,9 @@ def checkParameterValuesBeforeExecuting(alg, parameters, context):
     height = alg.parameterAsDouble(parameters, 'height', context)
     column = alg.parameterAsString(parameters, 'column', context)
     if (height and column) or (not height and not column):
-        return alg.tr("You need to set either a fixed height value or the height column!")
+        return False, alg.tr("You need to set either a fixed height value or the height column!")
 
-    return None
+    return True, None
 
 
 def processInputs(alg, parameters, context, feedback):
