@@ -23,7 +23,7 @@ __copyright__ = '(C) 2016, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 import os
 from collections import OrderedDict
@@ -32,6 +32,7 @@ from qgis.PyQt.QtGui import QIcon
 
 from qgis.analysis import QgsZonalStatistics
 from qgis.core import (QgsProcessing,
+                       QgsProcessingAlgorithm,
                        QgsProcessingParameterVectorLayer,
                        QgsProcessingParameterRasterLayer,
                        QgsProcessingParameterString,
@@ -61,8 +62,19 @@ class ZonalStatistics(QgisAlgorithm):
     def groupId(self):
         return 'rasteranalysis'
 
+    def flags(self):
+        return super().flags() | QgsProcessingAlgorithm.FlagNoThreading
+
     def __init__(self):
         super().__init__()
+        self.bandNumber = None
+        self.columnPrefix = None
+        self.selectedStats = None
+        self.vectorLayer = None
+        self.raster_interface = None
+        self.raster_crs = None
+        self.raster_units_per_pixel_x = None
+        self.raster_units_per_pixel_y = None
 
     def initAlgorithm(self, config=None):
         self.STATS = OrderedDict([(self.tr('Count'), QgsZonalStatistics.Count),
@@ -99,12 +111,6 @@ class ZonalStatistics(QgisAlgorithm):
                                                       self.tr('Zonal statistics'),
                                                       QgsProcessing.TypeVectorPolygon))
 
-        self.bandNumber = None
-        self.columnPrefix = None
-        self.selectedStats = None
-        self.vectorLayer = None
-        self.rasterLayer = None
-
     def name(self):
         return 'zonalstatistics'
 
@@ -122,12 +128,19 @@ class ZonalStatistics(QgisAlgorithm):
             self.selectedStats |= self.STATS[keys[i]]
 
         self.vectorLayer = self.parameterAsVectorLayer(parameters, self.INPUT_VECTOR, context)
-        self.rasterLayer = self.parameterAsRasterLayer(parameters, self.INPUT_RASTER, context)
+        rasterLayer = self.parameterAsRasterLayer(parameters, self.INPUT_RASTER, context)
+        self.raster_interface = rasterLayer.dataProvider().clone()
+        self.raster_crs = rasterLayer.crs()
+        self.raster_units_per_pixel_x = rasterLayer.rasterUnitsPerPixelX()
+        self.raster_units_per_pixel_y = rasterLayer.rasterUnitsPerPixelY()
         return True
 
     def processAlgorithm(self, parameters, context, feedback):
         zs = QgsZonalStatistics(self.vectorLayer,
-                                self.rasterLayer,
+                                self.raster_interface,
+                                self.raster_crs,
+                                self.raster_units_per_pixel_x,
+                                self.raster_units_per_pixel_y,
                                 self.columnPrefix,
                                 self.bandNumber,
                                 QgsZonalStatistics.Statistics(self.selectedStats))
