@@ -24,11 +24,10 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'a86bec25ebddd442bde3c6fe8ee761b22b36c26c'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 import os
 import importlib
-from copy import deepcopy
 from qgis.core import (Qgis,
                        QgsApplication,
                        QgsProcessingUtils,
@@ -113,7 +112,7 @@ class SagaAlgorithm(SagaAlgorithmBase):
         return super().flags() | QgsProcessingAlgorithm.FlagNoThreading
 
     def defineCharacteristicsFromFile(self):
-        with open(self.description_file) as lines:
+        with open(self.description_file, encoding="utf-8") as lines:
             line = lines.readline().strip('\n').strip()
             self._name = line
             if '|' in self._name:
@@ -148,11 +147,6 @@ class SagaAlgorithm(SagaAlgorithmBase):
                     self.params.append(getParameterFromString(line))
                 elif line.startswith('AllowUnmatching'):
                     self.allow_nonmatching_grid_extents = True
-                elif line.startswith('Extent'):
-                    # An extent parameter that wraps 4 SAGA numerical parameters
-                    self.extentParamNames = line[6:].strip().split(' ')
-                    self.params.append(QgsProcessingParameterExtent(self.OUTPUT_EXTENT,
-                                                                    'Output extent'))
                 else:
                     pass # TODO
                     #self.addOutput(getOutputFromString(line))
@@ -198,6 +192,9 @@ class SagaAlgorithm(SagaAlgorithmBase):
 
                 if not crs:
                     source = self.parameterAsSource(parameters, param.name(), context)
+                    if source is None:
+                        raise QgsProcessingException(self.invalidSourceError(parameters, param.name()))
+
                     crs = source.sourceCrs()
 
                 layer_path = self.parameterAsCompatibleSourceLayerPath(parameters, param.name(), context, ['shp'], 'shp', feedback=feedback)
@@ -228,15 +225,18 @@ class SagaAlgorithm(SagaAlgorithmBase):
 
                     self.exportedLayers[param.name()] = files
                 else:
-                    temp_params = deepcopy(parameters)
                     for layer in layers:
+                        temp_params = {}
                         temp_params[param.name()] = layer
 
                         if not crs:
                             source = self.parameterAsSource(temp_params, param.name(), context)
+                            if source is None:
+                                raise QgsProcessingException(self.invalidSourceError(parameters, param.name()))
+
                             crs = source.sourceCrs()
 
-                        layer_path = self.parameterAsCompatibleSourceLayerPath(temp_params, param.name(), context, 'shp',
+                        layer_path = self.parameterAsCompatibleSourceLayerPath(temp_params, param.name(), context, ['shp'], 'shp',
                                                                                feedback=feedback)
                         if layer_path:
                             if param.name() in self.exportedLayers:
@@ -260,7 +260,8 @@ class SagaAlgorithm(SagaAlgorithmBase):
             if isinstance(param, (QgsProcessingParameterRasterLayer, QgsProcessingParameterFeatureSource)):
                 command += ' -{} "{}"'.format(param.name(), self.exportedLayers[param.name()])
             elif isinstance(param, QgsProcessingParameterMultipleLayers):
-                command += ' -{} "{}"'.format(param.name(), ';'.join(self.exportedLayers[param.name()]))
+                if parameters[param.name()]: # parameter may have been an empty list
+                    command += ' -{} "{}"'.format(param.name(), ';'.join(self.exportedLayers[param.name()]))
             elif isinstance(param, QgsProcessingParameterBoolean):
                 if self.parameterAsBool(parameters, param.name(), context):
                     command += ' -{} true'.format(param.name().strip())
@@ -272,7 +273,7 @@ class SagaAlgorithm(SagaAlgorithmBase):
                     f.write('\t'.join([col for col in param.headers()]) + '\n')
                     values = self.parameterAsMatrix(parameters, param.name(), context)
                     for i in range(0, len(values), 3):
-                        s = values[i] + '\t' + values[i + 1] + '\t' + values[i + 2] + '\n'
+                        s = '{}\t{}\t{}\n'.format(values[i], values[i + 1], values[i + 2])
                         f.write(s)
                 command += ' -{} "{}"'.format(param.name(), tempTableFile)
             elif isinstance(param, QgsProcessingParameterExtent):
@@ -289,7 +290,7 @@ class SagaAlgorithm(SagaAlgorithmBase):
                 values.append(rect.yMaximum())
 
                 for i in range(4):
-                    command += ' -{} {}'.format(self.extentParamNames[i], float(values[i]) + offset[i])
+                    command += ' -{} {}'.format(param.name().split(' ')[i], float(values[i]) + offset[i])
             elif isinstance(param, QgsProcessingParameterNumber):
                 if param.dataType() == QgsProcessingParameterNumber.Integer:
                     command += ' -{} {}'.format(param.name(), self.parameterAsInt(parameters, param.name(), context))
@@ -413,17 +414,21 @@ class SagaAlgorithm(SagaAlgorithmBase):
         supported by SAGA, and that raster layers have the same grid extent
         """
         extent = None
-        layers = []
+        raster_layer_params = []
         for param in self.parameterDefinitions():
+            if param not in parameters or parameters[param.name()] is None:
+                continue
+
             if isinstance(param, QgsProcessingParameterRasterLayer):
-                layers.append(parameters[param.name()])
+                raster_layer_params.append(param.name())
             elif (isinstance(param, QgsProcessingParameterMultipleLayers) and
                     param.layerType() == QgsProcessing.TypeRaster):
-                if parameters[param.name()]:
-                    layers.extend(parameters[param.name()])
+                raster_layer_params.extend(param.name())
 
-        for layer in layers:
-            if layer is None or layer == '':
+        for layer_param in raster_layer_params:
+            layer = self.parameterAsRasterLayer(parameters, layer_param, context)
+
+            if layer is None:
                 continue
             if layer.bandCount() > 1:
                 return False, self.tr('Input layer {0} has more than one band.\n'
