@@ -25,9 +25,10 @@ __author__ = 'Victor Olaya'
 __date__ = 'August 2012'
 __copyright__ = '(C) 2012, Victor Olaya'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 import os
+import warnings
 
 from qgis.core import QgsSettings
 from qgis.PyQt import uic
@@ -36,8 +37,11 @@ from qgis.PyQt.QtWidgets import QDialog, QAbstractItemView, QPushButton, QDialog
 from qgis.PyQt.QtGui import QStandardItemModel, QStandardItem
 
 pluginPath = os.path.split(os.path.dirname(__file__))[0]
-WIDGET, BASE = uic.loadUiType(
-    os.path.join(pluginPath, 'ui', 'DlgMultipleSelection.ui'))
+
+with warnings.catch_warnings():
+    warnings.filterwarnings("ignore", category=DeprecationWarning)
+    WIDGET, BASE = uic.loadUiType(
+        os.path.join(pluginPath, 'ui', 'DlgMultipleSelection.ui'))
 
 
 class MultipleFileInputDialog(BASE, WIDGET):
