@@ -23,33 +23,10 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 import math
 
-from qgis.gui import QgsExpressionLineEdit, QgsProjectionSelectionWidget
-from qgis.core import (QgsSettings,
-                       QgsProcessing,
-                       QgsCoordinateReferenceSystem,
-                       QgsProcessingParameterDefinition,
-                       QgsProcessingParameterBoolean,
-                       QgsProcessingParameterCrs,
-                       QgsProcessingParameterMapLayer,
-                       QgsProcessingParameterExtent,
-                       QgsProcessingParameterPoint,
-                       QgsProcessingParameterFile,
-                       QgsProcessingParameterMatrix,
-                       QgsProcessingParameterMultipleLayers,
-                       QgsProcessingParameterNumber,
-                       QgsProcessingParameterRange,
-                       QgsProcessingParameterRasterLayer,
-                       QgsProcessingParameterEnum,
-                       QgsProcessingParameterString,
-                       QgsProcessingParameterExpression,
-                       QgsProcessingParameterVectorLayer,
-                       QgsProcessingParameterField,
-                       QgsProcessingParameterFeatureSource,
-                       QgsProcessingParameterBand)
 from qgis.PyQt.QtCore import (Qt,
                               QByteArray,
                               QCoreApplication)
@@ -62,41 +39,46 @@ from qgis.PyQt.QtWidgets import (QDialog,
                                  QDialogButtonBox,
                                  QMessageBox)
 
+from qgis.gui import QgsExpressionLineEdit, QgsProjectionSelectionWidget
+from qgis.core import (QgsApplication,
+                       QgsSettings,
+                       QgsProcessing,
+                       QgsCoordinateReferenceSystem,
+                       QgsProcessingParameterDefinition,
+                       QgsProcessingParameterBoolean,
+                       QgsProcessingParameterCrs,
+                       QgsProcessingParameterMapLayer,
+                       QgsProcessingParameterExtent,
+                       QgsProcessingParameterPoint,
+                       QgsProcessingParameterFile,
+                       QgsProcessingParameterMatrix,
+                       QgsProcessingParameterMultipleLayers,
+                       QgsProcessingParameterNumber,
+                       QgsProcessingParameterDistance,
+                       QgsProcessingParameterRange,
+                       QgsProcessingParameterRasterLayer,
+                       QgsProcessingParameterEnum,
+                       QgsProcessingParameterString,
+                       QgsProcessingParameterExpression,
+                       QgsProcessingParameterVectorLayer,
+                       QgsProcessingParameterField,
+                       QgsProcessingParameterFeatureSource,
+                       QgsProcessingParameterBand,
+                       QgsProcessingDestinationParameter,
+                       QgsProcessingParameterFeatureSink,
+                       QgsProcessingParameterFileDestination,
+                       QgsProcessingParameterFolderDestination,
+                       QgsProcessingParameterRasterDestination,
+                       QgsProcessingParameterVectorDestination)
+
+from processing.gui.DestinationSelectionPanel import DestinationSelectionPanel
+from processing.gui.enummodelerwidget import EnumModelerWidget
+from processing.gui.matrixmodelerwidget import MatrixModelerWidget
+from processing.core import parameters
+from processing.modeler.exceptions import UndefinedParameterException
+
 
 class ModelerParameterDefinitionDialog(QDialog):
-    PARAMETER_NUMBER = 'Number'
-    PARAMETER_RASTER = 'Raster Layer'
-    PARAMETER_TABLE = 'Vector Layer'
-    PARAMETER_VECTOR = 'Vector Features'
-    PARAMETER_STRING = 'String'
-    PARAMETER_EXPRESSION = 'Expression'
-    PARAMETER_BOOLEAN = 'Boolean'
-    PARAMETER_TABLE_FIELD = 'Vector Field'
-    PARAMETER_EXTENT = 'Extent'
-    PARAMETER_FILE = 'File'
-    PARAMETER_POINT = 'Point'
-    PARAMETER_CRS = 'CRS'
-    PARAMETER_MULTIPLE = 'Multiple Input'
-    PARAMETER_BAND = 'Raster Band'
-    PARAMETER_MAP_LAYER = 'Map Layer'
-
-    paramTypes = [
-        PARAMETER_BOOLEAN,
-        PARAMETER_EXTENT,
-        PARAMETER_FILE,
-        PARAMETER_NUMBER,
-        PARAMETER_RASTER,
-        PARAMETER_STRING,
-        PARAMETER_EXPRESSION,
-        PARAMETER_MAP_LAYER,
-        PARAMETER_TABLE,
-        PARAMETER_TABLE_FIELD,
-        PARAMETER_VECTOR,
-        PARAMETER_POINT,
-        PARAMETER_CRS,
-        PARAMETER_MULTIPLE,
-        PARAMETER_BAND
-    ]
 
     def __init__(self, alg, paramType=None, param=None):
         self.alg = alg
@@ -128,7 +110,7 @@ class ModelerParameterDefinitionDialog(QDialog):
         if isinstance(self.param, QgsProcessingParameterDefinition):
             self.nameTextBox.setText(self.param.description())
 
-        if self.paramType == ModelerParameterDefinitionDialog.PARAMETER_BOOLEAN or \
+        if self.paramType == parameters.PARAMETER_BOOLEAN or \
                 isinstance(self.param, QgsProcessingParameterBoolean):
             self.state = QCheckBox()
             self.state.setText(self.tr('Checked'))
@@ -136,7 +118,7 @@ class ModelerParameterDefinitionDialog(QDialog):
             if self.param is not None:
                 self.state.setChecked(bool(self.param.defaultValue()))
             self.verticalLayout.addWidget(self.state)
-        elif self.paramType == ModelerParameterDefinitionDialog.PARAMETER_TABLE_FIELD or \
+        elif self.paramType == parameters.PARAMETER_TABLE_FIELD or \
                 isinstance(self.param, QgsProcessingParameterField):
             self.verticalLayout.addWidget(QLabel(self.tr('Parent layer')))
             self.parentCombo = QComboBox()
@@ -183,7 +165,7 @@ class ModelerParameterDefinitionDialog(QDialog):
                     self.defaultTextBox.setText(str(default))
             self.verticalLayout.addWidget(self.defaultTextBox)
 
-        elif self.paramType == ModelerParameterDefinitionDialog.PARAMETER_BAND or \
+        elif self.paramType == parameters.PARAMETER_BAND or \
                 isinstance(self.param, QgsProcessingParameterBand):
             self.verticalLayout.addWidget(QLabel(self.tr('Parent layer')))
             self.parentCombo = QComboBox()
@@ -198,7 +180,7 @@ class ModelerParameterDefinitionDialog(QDialog):
                     idx += 1
             self.verticalLayout.addWidget(self.parentCombo)
         elif (self.paramType in (
-                ModelerParameterDefinitionDialog.PARAMETER_VECTOR, ModelerParameterDefinitionDialog.PARAMETER_TABLE) or
+                parameters.PARAMETER_VECTOR, parameters.PARAMETER_TABLE) or
                 isinstance(self.param, (QgsProcessingParameterFeatureSource, QgsProcessingParameterVectorLayer))):
             self.verticalLayout.addWidget(QLabel(self.tr('Geometry type')))
             self.shapetypeCombo = QComboBox()
@@ -210,7 +192,7 @@ class ModelerParameterDefinitionDialog(QDialog):
             if self.param is not None:
                 self.shapetypeCombo.setCurrentIndex(self.shapetypeCombo.findData(self.param.dataTypes()[0]))
             self.verticalLayout.addWidget(self.shapetypeCombo)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_MULTIPLE or
+        elif (self.paramType == parameters.PARAMETER_MULTIPLE or
               isinstance(self.param, QgsProcessingParameterMultipleLayers)):
             self.verticalLayout.addWidget(QLabel(self.tr('Data type')))
             self.datatypeCombo = QComboBox()
@@ -225,8 +207,8 @@ class ModelerParameterDefinitionDialog(QDialog):
             if self.param is not None:
                 self.datatypeCombo.setCurrentIndex(self.datatypeCombo.findData(self.param.layerType()))
             self.verticalLayout.addWidget(self.datatypeCombo)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_NUMBER or
-              isinstance(self.param, QgsProcessingParameterNumber)):
+        elif (self.paramType == parameters.PARAMETER_NUMBER or self.paramType == parameters.PARAMETER_DISTANCE or
+              isinstance(self.param, (QgsProcessingParameterNumber, QgsProcessingParameterDistance))):
             self.verticalLayout.addWidget(QLabel(self.tr('Min value')))
             self.minTextBox = QLineEdit()
             self.verticalLayout.addWidget(self.minTextBox)
@@ -246,7 +228,7 @@ class ModelerParameterDefinitionDialog(QDialog):
                 if default:
                     self.defaultTextBox.setText(str(default))
             self.verticalLayout.addWidget(self.defaultTextBox)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_EXPRESSION or
+        elif (self.paramType == parameters.PARAMETER_EXPRESSION or
               isinstance(self.param, QgsProcessingParameterExpression)):
             self.verticalLayout.addWidget(QLabel(self.tr('Default value')))
             self.defaultEdit = QgsExpressionLineEdit()
@@ -267,14 +249,14 @@ class ModelerParameterDefinitionDialog(QDialog):
                             self.parentCombo.setCurrentIndex(idx)
                     idx += 1
             self.verticalLayout.addWidget(self.parentCombo)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_STRING or
+        elif (self.paramType == parameters.PARAMETER_STRING or
               isinstance(self.param, QgsProcessingParameterString)):
             self.verticalLayout.addWidget(QLabel(self.tr('Default value')))
             self.defaultTextBox = QLineEdit()
             if self.param is not None:
                 self.defaultTextBox.setText(self.param.defaultValue())
             self.verticalLayout.addWidget(self.defaultTextBox)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_FILE or
+        elif (self.paramType == parameters.PARAMETER_FILE or
               isinstance(self.param, QgsProcessingParameterFile)):
             self.verticalLayout.addWidget(QLabel(self.tr('Type')))
             self.fileFolderCombo = QComboBox()
@@ -284,14 +266,14 @@ class ModelerParameterDefinitionDialog(QDialog):
                 self.fileFolderCombo.setCurrentIndex(
                     1 if self.param.behavior() == QgsProcessingParameterFile.Folder else 0)
             self.verticalLayout.addWidget(self.fileFolderCombo)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_POINT or
+        elif (self.paramType == parameters.PARAMETER_POINT or
               isinstance(self.param, QgsProcessingParameterPoint)):
             self.verticalLayout.addWidget(QLabel(self.tr('Default value')))
             self.defaultTextBox = QLineEdit()
             if self.param is not None:
                 self.defaultTextBox.setText(self.param.defaultValue())
             self.verticalLayout.addWidget(self.defaultTextBox)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_CRS or
+        elif (self.paramType == parameters.PARAMETER_CRS or
               isinstance(self.param, QgsProcessingParameterCrs)):
             self.verticalLayout.addWidget(QLabel(self.tr('Default value')))
             self.selector = QgsProjectionSelectionWidget()
@@ -300,6 +282,26 @@ class ModelerParameterDefinitionDialog(QDialog):
             else:
                 self.selector.setCrs(QgsCoordinateReferenceSystem('EPSG:4326'))
             self.verticalLayout.addWidget(self.selector)
+        elif self.paramType == parameters.PARAMETER_ENUM or \
+                isinstance(self.param, QgsProcessingParameterEnum):
+            self.widget = EnumModelerWidget(self)
+            if self.param is not None:
+                self.widget.setAllowMultiple(bool(self.param.allowMultiple()))
+                self.widget.setOptions(self.param.options())
+                self.widget.setDefault(self.param.defaultValue())
+            self.verticalLayout.addWidget(self.widget)
+        elif self.paramType == parameters.PARAMETER_MATRIX or \
+                isinstance(self.param, QgsProcessingParameterMatrix):
+            self.widget = MatrixModelerWidget(self)
+            if self.param is not None:
+                self.widget.setValue(self.param.headers(), self.param.defaultValue())
+                self.widget.setFixedRows(self.param.hasFixedNumberRows())
+            self.verticalLayout.addWidget(self.widget)
+
+        elif isinstance(self.param, QgsProcessingDestinationParameter):
+            self.verticalLayout.addWidget(QLabel(self.tr('Default value')))
+            self.defaultWidget = DestinationSelectionPanel(self.param, self.alg, default_selection=True)
+            self.verticalLayout.addWidget(self.defaultWidget)
 
         self.verticalLayout.addSpacing(20)
         self.requiredCheck = QCheckBox()
@@ -309,6 +311,16 @@ class ModelerParameterDefinitionDialog(QDialog):
             self.requiredCheck.setChecked(not self.param.flags() & QgsProcessingParameterDefinition.FlagOptional)
         self.verticalLayout.addWidget(self.requiredCheck)
 
+        # If child algorithm output is mandatory, disable checkbox
+        if isinstance(self.param, QgsProcessingDestinationParameter):
+            provider_name, child_name, output_name = self.param.name().split(':')
+            child = self.alg.childAlgorithms()['{}:{}'.format(provider_name, child_name)]
+            model_output = child.modelOutput(output_name)
+            param_def = child.algorithm().parameterDefinition(model_output.childOutputName())
+            if not (param_def.flags() & QgsProcessingParameterDefinition.FlagOptional):
+                self.requiredCheck.setEnabled(False)
+                self.requiredCheck.setChecked(True)
+
         self.buttonBox = QDialogButtonBox(self)
         self.buttonBox.setOrientation(Qt.Horizontal)
         self.buttonBox.setStandardButtons(QDialogButtonBox.Cancel |
@@ -323,7 +335,7 @@ class ModelerParameterDefinitionDialog(QDialog):
         self.setLayout(self.verticalLayout)
 
     def accept(self):
-        description = str(self.nameTextBox.text())
+        description = self.nameTextBox.text()
         if description.strip() == '':
             QMessageBox.warning(self, self.tr('Unable to define parameter'),
                                 self.tr('Invalid parameter name'))
@@ -339,10 +351,10 @@ class ModelerParameterDefinitionDialog(QDialog):
                 i += 1
         else:
             name = self.param.name()
-        if (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_BOOLEAN or
+        if (self.paramType == parameters.PARAMETER_BOOLEAN or
                 isinstance(self.param, QgsProcessingParameterBoolean)):
             self.param = QgsProcessingParameterBoolean(name, description, self.state.isChecked())
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_TABLE_FIELD or
+        elif (self.paramType == parameters.PARAMETER_TABLE_FIELD or
               isinstance(self.param, QgsProcessingParameterField)):
             if self.parentCombo.currentIndex() < 0:
                 QMessageBox.warning(self, self.tr('Unable to define parameter'),
@@ -356,7 +368,7 @@ class ModelerParameterDefinitionDialog(QDialog):
             self.param = QgsProcessingParameterField(name, description, defaultValue=default,
                                                      parentLayerParameterName=parent, type=datatype,
                                                      allowMultiple=self.multipleCheck.isChecked())
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_BAND or
+        elif (self.paramType == parameters.PARAMETER_BAND or
               isinstance(self.param, QgsProcessingParameterBand)):
             if self.parentCombo.currentIndex() < 0:
                 QMessageBox.warning(self, self.tr('Unable to define parameter'),
@@ -364,31 +376,31 @@ class ModelerParameterDefinitionDialog(QDialog):
                 return
             parent = self.parentCombo.currentData()
             self.param = QgsProcessingParameterBand(name, description, None, parent)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_MAP_LAYER or
+        elif (self.paramType == parameters.PARAMETER_MAP_LAYER or
               isinstance(self.param, QgsProcessingParameterMapLayer)):
             self.param = QgsProcessingParameterMapLayer(
                 name, description)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_RASTER or
+        elif (self.paramType == parameters.PARAMETER_RASTER or
               isinstance(self.param, QgsProcessingParameterRasterLayer)):
             self.param = QgsProcessingParameterRasterLayer(
                 name, description)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_TABLE or
+        elif (self.paramType == parameters.PARAMETER_TABLE or
               isinstance(self.param, QgsProcessingParameterVectorLayer)):
             self.param = QgsProcessingParameterVectorLayer(
                 name, description,
                 [self.shapetypeCombo.currentData()])
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_VECTOR or
+        elif (self.paramType == parameters.PARAMETER_VECTOR or
               isinstance(self.param, QgsProcessingParameterFeatureSource)):
             self.param = QgsProcessingParameterFeatureSource(
                 name, description,
                 [self.shapetypeCombo.currentData()])
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_MULTIPLE or
+        elif (self.paramType == parameters.PARAMETER_MULTIPLE or
               isinstance(self.param, QgsProcessingParameterMultipleLayers)):
             self.param = QgsProcessingParameterMultipleLayers(
                 name, description,
                 self.datatypeCombo.currentData())
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_NUMBER or
-              isinstance(self.param, QgsProcessingParameterNumber)):
+        elif (self.paramType == parameters.PARAMETER_NUMBER or
+              isinstance(self.param, (QgsProcessingParameterNumber, QgsProcessingParameterDistance))):
             try:
                 self.param = QgsProcessingParameterNumber(name, description, QgsProcessingParameterNumber.Double,
                                                           self.defaultTextBox.text())
@@ -402,33 +414,86 @@ class ModelerParameterDefinitionDialog(QDialog):
                 QMessageBox.warning(self, self.tr('Unable to define parameter'),
                                     self.tr('Wrong or missing parameter values'))
                 return
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_EXPRESSION or
+        elif (self.paramType == parameters.PARAMETER_EXPRESSION or
               isinstance(self.param, QgsProcessingParameterExpression)):
             parent = self.parentCombo.currentData()
             self.param = QgsProcessingParameterExpression(name, description,
                                                           str(self.defaultEdit.expression()),
                                                           parent)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_STRING or
+        elif (self.paramType == parameters.PARAMETER_STRING or
               isinstance(self.param, QgsProcessingParameterString)):
             self.param = QgsProcessingParameterString(name, description,
                                                       str(self.defaultTextBox.text()))
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_EXTENT or
+        elif (self.paramType == parameters.PARAMETER_EXTENT or
               isinstance(self.param, QgsProcessingParameterExtent)):
             self.param = QgsProcessingParameterExtent(name, description)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_FILE or
+        elif (self.paramType == parameters.PARAMETER_FILE or
               isinstance(self.param, QgsProcessingParameterFile)):
             isFolder = self.fileFolderCombo.currentIndex() == 1
             self.param = QgsProcessingParameterFile(name, description,
                                                     QgsProcessingParameterFile.Folder if isFolder else QgsProcessingParameterFile.File)
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_POINT or
+        elif (self.paramType == parameters.PARAMETER_POINT or
               isinstance(self.param, QgsProcessingParameterPoint)):
             self.param = QgsProcessingParameterPoint(name, description,
                                                      str(self.defaultTextBox.text()))
-        elif (self.paramType == ModelerParameterDefinitionDialog.PARAMETER_CRS or
+        elif (self.paramType == parameters.PARAMETER_CRS or
               isinstance(self.param, QgsProcessingParameterCrs)):
             self.param = QgsProcessingParameterCrs(name, description, self.selector.crs().authid())
+        elif (self.paramType == parameters.PARAMETER_ENUM or
+                isinstance(self.param, QgsProcessingParameterEnum)):
+            self.param = QgsProcessingParameterEnum(name, description, self.widget.options(), self.widget.allowMultiple(), self.widget.defaultOptions())
+        elif (self.paramType == parameters.PARAMETER_MATRIX or
+                isinstance(self.param, QgsProcessingParameterMatrix)):
+            self.param = QgsProcessingParameterMatrix(name, description, hasFixedNumberRows=self.widget.fixedRows(), headers=self.widget.headers(), defaultValue=self.widget.value())
+
+        # Destination parameter
+        elif (isinstance(self.param, QgsProcessingParameterFeatureSink)):
+            self.param = QgsProcessingParameterFeatureSink(
+                name=name,
+                description=self.param.description(),
+                type=self.param.dataType(),
+                defaultValue=self.defaultWidget.getValue())
+        elif (isinstance(self.param, QgsProcessingParameterFileDestination)):
+            self.param = QgsProcessingParameterFileDestination(
+                name=name,
+                description=self.param.description(),
+                fileFilter=self.param.fileFilter(),
+                defaultValue=self.defaultWidget.getValue())
+        elif (isinstance(self.param, QgsProcessingParameterFolderDestination)):
+            self.param = QgsProcessingParameterFolderDestination(
+                name=name,
+                description=self.param.description(),
+                defaultValue=self.defaultWidget.getValue())
+        elif (isinstance(self.param, QgsProcessingParameterRasterDestination)):
+            self.param = QgsProcessingParameterRasterDestination(
+                name=name,
+                description=self.param.description(),
+                defaultValue=self.defaultWidget.getValue())
+        elif (isinstance(self.param, QgsProcessingParameterVectorDestination)):
+            self.param = QgsProcessingParameterVectorDestination(
+                name=name,
+                description=self.param.description(),
+                type=self.param.dataType(),
+                defaultValue=self.defaultWidget.getValue())
+
+        else:
+            if self.paramType:
+                typeId = self.paramType
+            else:
+                typeId = self.param.type()
+
+            paramTypeDef = QgsApplication.instance().processingRegistry().parameterType(typeId)
+            if not paramTypeDef:
+                msg = self.tr('The parameter `{}` is not registered, are you missing a required plugin?'.format(typeId))
+                raise UndefinedParameterException(msg)
+            self.param = paramTypeDef.create(name)
+            self.param.setDescription(description)
+            self.param.setMetadata(paramTypeDef.metadata())
+
         if not self.requiredCheck.isChecked():
             self.param.setFlags(self.param.flags() | QgsProcessingParameterDefinition.FlagOptional)
+        else:
+            self.param.setFlags(self.param.flags() & ~QgsProcessingParameterDefinition.FlagOptional)
 
         settings = QgsSettings()
         settings.setValue("/Processing/modelParametersDefinitionDialogGeometry", self.saveGeometry())
@@ -442,24 +507,3 @@ class ModelerParameterDefinitionDialog(QDialog):
         settings.setValue("/Processing/modelParametersDefinitionDialogGeometry", self.saveGeometry())
 
         QDialog.reject(self)
-
-    @staticmethod
-    def inputTooltip(input_type):
-        tooltips = {
-            ModelerParameterDefinitionDialog.PARAMETER_NUMBER: QCoreApplication.translate('Processing', 'A numeric parameter, including float or integer values.'),
-            ModelerParameterDefinitionDialog.PARAMETER_RASTER: QCoreApplication.translate('Processing', 'A raster layer parameter.'),
-            ModelerParameterDefinitionDialog.PARAMETER_TABLE: QCoreApplication.translate('Processing', 'A vector layer parameter, e.g. for algorithms which change layer styles, edit layers in place, or other operations which affect an entire layer.'),
-            ModelerParameterDefinitionDialog.PARAMETER_VECTOR: QCoreApplication.translate('Processing', 'A vector feature parameter, e.g. for algorithms which operate on the features within a layer.'),
-            ModelerParameterDefinitionDialog.PARAMETER_STRING: QCoreApplication.translate('Processing', 'A freeform string parameter.'),
-            ModelerParameterDefinitionDialog.PARAMETER_EXPRESSION: QCoreApplication.translate('Processing', 'A QGIS expression parameter, which presents an expression builder widget to users.'),
-            ModelerParameterDefinitionDialog.PARAMETER_BOOLEAN: QCoreApplication.translate('Processing', 'A boolean parameter, for true/false values.'),
-            ModelerParameterDefinitionDialog.PARAMETER_TABLE_FIELD: QCoreApplication.translate('Processing', 'A vector field parameter, for selecting an existing field from a vector source.'),
-            ModelerParameterDefinitionDialog.PARAMETER_EXTENT: QCoreApplication.translate('Processing', 'A map extent parameter.'),
-            ModelerParameterDefinitionDialog.PARAMETER_FILE: QCoreApplication.translate('Processing', 'A file parameter, for use with non-map layer file sources.'),
-            ModelerParameterDefinitionDialog.PARAMETER_POINT: QCoreApplication.translate('Processing', 'A geographic point parameter.'),
-            ModelerParameterDefinitionDialog.PARAMETER_CRS: QCoreApplication.translate('Processing', 'A coordinate reference system (CRS) input parameter.'),
-            ModelerParameterDefinitionDialog.PARAMETER_MULTIPLE: QCoreApplication.translate('Processing', 'An input allowing selection of multiple sources, including multiple map layers or file sources.'),
-            ModelerParameterDefinitionDialog.PARAMETER_BAND: QCoreApplication.translate('Processing', 'A raster band parameter, for selecting an existing band from a raster source.'),
-            ModelerParameterDefinitionDialog.PARAMETER_MAP_LAYER: QCoreApplication.translate('Processing', 'A generic map layer parameter, which accepts either vector or raster layers.')
-        }
-        return tooltips[input_type]
